import React, { useEffect, useState } from 'react'
import CircularProgress from '@material-ui/core/CircularProgress';
import { EditKlinkDetails, KlinkDetails, ViewKlinkDetails } from '../../../common/types'
import KlinkErrorDialog from '../KlinkErrorDialog'
import KlinkDetailsView from '../KlinkDetails'

type Props = {
  token: string
  readKlink: (token: string) => Promise<ViewKlinkDetails | EditKlinkDetails>
  editKlink: (klinkRequest: KlinkDetails) => Promise<void>
  close: () => void
}

const KlinkDetailsDialog = ({ token, readKlink, editKlink, close }: Props) => {
  const [data, setData] = useState<ViewKlinkDetails | EditKlinkDetails | null>(null)
  const [error, setError] = useState<string | null>(null)

  useEffect(() => {
    readKlink(token)
      .then((data) => setData(data))
      .catch((error) => setError(error))

    return () => {
      setData(null)
      setError(null)
    }
  }, [readKlink, token])

  if (error !== null) {
    return <KlinkErrorDialog message={error} close={window.api.close} />
  }

  return (
    <>
      {data ? (
        <KlinkDetailsView data={data} editKlink={editKlink} close={close} />
      ) : (
        <CircularProgress />
      )}
    </>
  )
}

export default KlinkDetailsDialog
