import React from 'react'
import Checkbox from '@material-ui/core/Checkbox'
import ShareWithField from './ShareWithField'
import { Contact, KlinkDetailsWithContacts } from '../../types'
import { TitleInput, DataInput, NotificationsLabel } from './styles'

type Props = {
  title?: string,
  body: string,
  sharedWith?: Contact[],
  notifications?: boolean,
  onChange(klinkRequest: KlinkDetailsWithContacts): void,
}

const KlinkDetailsForm = ({
  title = '',
  body,
  sharedWith = [],
  notifications = false,
  onChange,
}: Props) => {
  const cloneDetails = (merge: Partial<KlinkDetailsWithContacts>): KlinkDetailsWithContacts => {
    return {
      title,
      body,
      sharedWith,
      notifications,
      ...merge,
    }
  }

  return (
    <div>
      <div>
        <div>
          <ShareWithField values={sharedWith} onChange={(value) => onChange(cloneDetails({ sharedWith: value }))} />
        </div>
      </div>
      <div>
        <NotificationsLabel
          control={<Checkbox color="primary"
            checked={notifications}
            onChange={e => onChange(cloneDetails({ notifications: e.target.checked }))} />}
          label="Enable notifications"
          labelPlacement="start"
        />
      </div>
      <div>
        <h3>Shared content</h3>
        <TitleInput
          label="Title"
          id="outlined-size-small"
          variant="outlined"
          size="small"
          value={title}
          onChange={e => onChange(cloneDetails({ title: e.target.value }))}
        />
      </div>
      <div>
        <DataInput
          id="outlined-multiline-flexible"
          label="Data"
          multiline
          maxRows={4}
          value={body}
          onChange={e => onChange(cloneDetails({ body: e.target.value }))}
          variant="outlined"
        />
      </div>
    </div>
  )
}

export default KlinkDetailsForm
